@@ -16,24 +16,24 @@ import           Control.Arrow
 import           Control.Monad
 import           Control.Monad.RWS.Strict
 import           Control.Monad.State.Strict
-import qualified Data.Attoparsec.Text            as AP
-import           Data.ByteString (ByteString)
-import           Data.DList                      (DList)
-import qualified Data.DList                      as DL
-import qualified Data.HashMap.Strict             as H
-import qualified Data.HashSet                    as S
-import qualified Data.HeterogeneousEnvironment   as HE
+import qualified Data.Attoparsec.Text               as AP
+import           Data.ByteString                    (ByteString)
+import           Data.DList                         (DList)
+import qualified Data.DList                         as DL
+import qualified Data.HashMap.Strict                as H
+import qualified Data.HashSet                       as S
+import qualified Data.HeterogeneousEnvironment      as HE
+import           Data.Map.Syntax
 import           Data.Maybe
-import           Data.Text                       (Text)
-import qualified Data.Text                       as T
-import qualified Data.Text.Encoding              as T
-import qualified Data.Vector                     as V
-import qualified Text.XmlHtml                    as X
-import qualified Text.XmlHtml.HTML.Meta          as X
+import           Data.Text                          (Text)
+import qualified Data.Text                          as T
+import qualified Data.Text.Encoding                 as T
+import qualified Data.Vector                        as V
+import qualified Text.XmlHtml                       as X
+import qualified Text.XmlHtml.HTML.Meta             as X
 ------------------------------------------------------------------------------
 import           Heist.Common
-import           Heist.SpliceAPI
-import           Heist.Types
+import           Heist.Internal.Types.HeistState
 ------------------------------------------------------------------------------
 
 
@@ -121,18 +121,6 @@ runNodeList :: Monad n => [X.Node] -> Splice n
 runNodeList = mapSplices runNode
 
 
-------------------------------------------------------------------------------
--- | Runs a single splice and returns the builder computation.
-runSplice :: (Monad n)
-          => X.Node
-          -> HeistState n
-          -> Splice n
-          -> IO [Chunk n]
-runSplice node hs splice = do
-    !a <- evalHeistT splice node hs
-    return $! consolidate a
-
-
 ------------------------------------------------------------------------------
 -- | Runs a DocumentFile with the appropriate template context set.
 runDocumentFile :: Monad n
@@ -140,6 +128,10 @@ runDocumentFile :: Monad n
                 -> DocumentFile
                 -> Splice n
 runDocumentFile tpath df = do
+    let markup = case dfDoc df of
+                   X.XmlDocument _ _ _ -> Xml
+                   X.HtmlDocument _ _ _ -> Html
+    modifyHS (\hs -> hs { _curMarkup = markup })
     addDoctype $ maybeToList $ X.docType $ dfDoc df
     modifyHS (setCurTemplateFile curPath .  setCurContext tpath)
     res <- runNodeList nodes
@@ -152,46 +144,41 @@ runDocumentFile tpath df = do
 
 
 ------------------------------------------------------------------------------
-compileTemplate :: Monad n
-                => HeistState n
-                -> TPath
-                -> DocumentFile
-                -> IO [Chunk n]
-compileTemplate hs tpath df = do
-    let markup = case dfDoc df of
-                   X.XmlDocument _ _ _ -> Xml
-                   X.HtmlDocument _ _ _ -> Html
-        hs' = hs { _curMarkup = markup }
-    !chunks <- runSplice nullNode hs' $! runDocumentFile tpath df
-    return chunks
-  where
-    -- This gets overwritten in runDocumentFile
-    nullNode = X.TextNode ""
+compileTemplate
+    :: Monad n
+    => TPath
+    -> DocumentFile
+    -> HeistT n IO [Chunk n]
+compileTemplate tpath df = do
+    !chunks <- runDocumentFile tpath df
+    return $! consolidate chunks
 
 
 ------------------------------------------------------------------------------
-compileTemplates :: Monad n => HeistState n -> IO (HeistState n)
+compileTemplates
+    :: Monad n
+    => HeistState n
+    -> IO (Either [String] (HeistState n))
 compileTemplates hs = do
-    ctm <- compileTemplates' hs
-    return $! hs { _compiledTemplateMap = ctm }
---    let f = flip evalStateT HE.empty . unRT . codeGen
---    return $! hs { _compiledTemplateMap = H.map (first f) ctm }
+    (tmap, hs') <- runHeistT compileTemplates' (X.TextNode "") hs
+    return $ case _spliceErrors hs' of
+               [] -> Right $! hs { _compiledTemplateMap = tmap }
+               es -> Left $ map T.unpack es
 
 
 ------------------------------------------------------------------------------
-compileTemplates' :: Monad n
-                  => HeistState n
-                  -> IO (H.HashMap TPath ([Chunk n], MIMEType))
-compileTemplates' hs = do
-    ctm <- foldM runOne H.empty tpathDocfiles
-    return $! ctm
+compileTemplates'
+    :: Monad n
+    => HeistT n IO (H.HashMap TPath ([Chunk n], MIMEType))
+compileTemplates' = do
+    hs <- getHS
+    let tpathDocfiles :: [(TPath, DocumentFile)]
+        tpathDocfiles = map (\(a,b) -> (a, b))
+                            (H.toList $ _templateMap hs)
+    foldM runOne H.empty tpathDocfiles
   where
-    tpathDocfiles :: [(TPath, DocumentFile)]
-    tpathDocfiles = map (\(a,b) -> (a, b))
-                        (H.toList $ _templateMap hs)
-
     runOne tmap (tpath, df) = do
-        !mHtml <- compileTemplate hs tpath df
+        !mHtml <- compileTemplate tpath df
         return $! H.insert tpath (mHtml, mimeType $! dfDoc df) tmap
 
 
@@ -205,29 +192,29 @@ consolidate = consolidateL . DL.toList
       where
         ----------------------------------------------------------------------
         go soFar x [] = x : soFar
-    
+
         go soFar (Pure a) ((Pure b) : xs) =
             go soFar (Pure $! a `mappend` b) xs
-    
+
         go soFar (RuntimeHtml a) ((RuntimeHtml b) : xs) =
             go soFar (RuntimeHtml $! a `mappend` b) xs
-    
+
         go soFar (RuntimeHtml a) ((RuntimeAction b) : xs) =
             go soFar (RuntimeHtml $! a >>= \x -> b >> return x) xs
-    
+
         go soFar (RuntimeAction a) ((RuntimeHtml b) : xs) =
             go soFar (RuntimeHtml $! a >> b) xs
-    
+
         go soFar (RuntimeAction a) ((RuntimeAction b) : xs) =
             go soFar (RuntimeAction $! a >> b) xs
-    
+
         go soFar a (b : xs) = go (a : soFar) b xs
-    
+
         ----------------------------------------------------------------------
         boilDown soFar []              = soFar
-    
+
         boilDown soFar ((Pure h) : xs) = boilDown ((Pure $! h) : soFar) xs
-    
+
         boilDown soFar (x : xs) = boilDown (x : soFar) xs
 
 
@@ -248,7 +235,16 @@ codeGen l = V.foldr mappend mempty $!
 ------------------------------------------------------------------------------
 -- | Looks up a splice in the compiled splice map.
 lookupSplice :: Text -> HeistT n IO (Maybe (Splice n))
-lookupSplice nm = getsHS (H.lookup nm . _compiledSpliceMap)
+lookupSplice nm = do
+    pre <- getsHS _splicePrefix
+    res <- getsHS (H.lookup nm . _compiledSpliceMap)
+    canError <- getsHS _errorNotBound
+    if isNothing res && T.isPrefixOf pre nm && not (T.null pre)
+      then do
+          when canError $
+            tellSpliceError $ "No splice bound for " `mappend` nm
+          return Nothing
+      else return res
 
 
 ------------------------------------------------------------------------------
@@ -317,9 +313,9 @@ hasAttributeSubstitutions txt = any isIdent ast
 -- | Given a 'X.Node' in the DOM tree, produces a \"runtime splice\" that will
 -- generate html at runtime.
 compileNode :: Monad n => X.Node -> Splice n
-compileNode (X.Element nm attrs ch) =
-    -- Is this node a splice, or does it merely contain splices?
-    lookupSplice nm >>= fromMaybe compileStaticElement
+compileNode (X.Element nm attrs ch) = do
+    msplice <- lookupSplice nm
+    fromMaybe compileStaticElement msplice
   where
     tag0 = T.append "<" nm
     end = T.concat [ "</" , nm , ">"]
@@ -429,7 +425,7 @@ attrToChunk !k !v = do
     DL.concat
         [ DL.singleton $! pureTextChunk $! T.concat [" ", k, "=\""]
         , v, DL.singleton $! pureTextChunk "\"" ]
-    
+
 
 attrToBuilder :: (Text, Text) -> Builder
 attrToBuilder (k,v)
@@ -538,7 +534,9 @@ bindSplice n v ts =
 bindSplices :: Splices (Splice n)  -- ^ splices to bind
             -> HeistState n        -- ^ source state
             -> HeistState n
-bindSplices ss ts = foldr (uncurry bindSplice) ts $ splicesToList ss
+bindSplices ss hs =
+    hs { _compiledSpliceMap = H.union (runMapNoErrors ss)
+                                      (_compiledSpliceMap hs) }
 
 
 ------------------------------------------------------------------------------
@@ -598,6 +596,20 @@ nodeSplice :: (a -> [X.Node]) -> a -> Builder
 nodeSplice f = X.renderHtmlFragment X.UTF8 . f
 
 
+------------------------------------------------------------------------------
+-- | Converts a pure XML Node splice function to a pure Builder splice
+-- function.
+xmlNodeSplice :: (a -> [X.Node]) -> a -> Builder
+xmlNodeSplice f = X.renderXmlFragment X.UTF8 . f
+
+
+------------------------------------------------------------------------------
+-- | Converts a pure HTML Node splice function to a pure Builder splice
+-- function.
+htmlNodeSplice :: (a -> [X.Node]) -> a -> Builder
+htmlNodeSplice f = X.renderHtmlFragment X.UTF8 . f
+
+
 ------------------------------------------------------------------------------
 -- | Converts a pure Builder splice function into a monadic splice function
 -- of a RuntimeSplice.
@@ -617,9 +629,9 @@ withSplices :: Monad n
             -- ^ Runtime data needed by the above splices
             -> Splice n
 withSplices splice splices runtimeAction =
-    withLocalSplices splices' noSplices splice
+    withLocalSplices splices' mempty splice
   where
-    splices' = mapS ($runtimeAction) splices
+    splices' = mapV ($runtimeAction) splices
 
 
 ------------------------------------------------------------------------------
@@ -632,8 +644,8 @@ manyWithSplices :: Monad n
                 -> Splice n
 manyWithSplices splice splices runtimeAction = do
     p <- newEmptyPromise
-    let splices' = mapS ($ getPromise p) splices
-    chunks <- withLocalSplices splices' noSplices splice
+    let splices' = mapV ($ getPromise p) splices
+    chunks <- withLocalSplices splices' mempty splice
     return $ yieldRuntime $ do
         items <- runtimeAction
         res <- forM items $ \item -> putPromise p item >> codeGen chunks
@@ -651,8 +663,8 @@ manyWith :: (Monad n)
          -> Splice n
 manyWith splice splices attrSplices runtimeAction = do
     p <- newEmptyPromise
-    let splices' = mapS ($ getPromise p) splices
-    let attrSplices' = mapS ($ getPromise p) attrSplices
+    let splices' = mapV ($ getPromise p) splices
+    let attrSplices' = mapV ($ getPromise p) attrSplices
     chunks <- withLocalSplices splices' attrSplices' splice
     return $ yieldRuntime $ do
         items <- runtimeAction
@@ -697,7 +709,7 @@ deferMap f pf n = do
 -- | Like deferMap, but only runs the result if a Maybe function of the
 -- runtime value returns Just.  If it returns Nothing, then no output is
 -- generated.
--- 
+--
 -- This is a good example of how to do more complex flow control with
 -- promises.  The generalization of this abstraction is too complex to be
 -- distilled to elegant high-level combinators.  If you need to implement your
