@@ -10,7 +10,7 @@ import qualified Text.XmlHtml as X
 import           Heist.Common
 import           Heist.Interpreted.Internal
 import           Heist.Splices.Apply
-import           Heist.Types
+import           Heist.Internal.Types.HeistState
 
 -- | Default name for the bind splice.
 bindTag :: Text
