@@ -1,3 +1,4 @@
+{-# LANGUAGE FlexibleContexts #-}
 {-|
 
 This module defines a TemplateDirectory data structure for convenient
@@ -17,9 +18,9 @@ module Heist.TemplateDirectory
 
 ------------------------------------------------------------------------------
 import           Control.Concurrent
-import           Control.Error
 import           Control.Monad
 import           Control.Monad.Trans
+import           Control.Monad.Trans.Either
 import           Heist
 import           Heist.Internal.Types
 import           Heist.Splices.Cache
