@@ -14,20 +14,21 @@ import           Blaze.ByteString.Builder
 import           Control.Error
 import           Control.Monad.State
 import           Data.Aeson
-import           Data.ByteString.Char8 (ByteString)
-import qualified Data.ByteString.Char8 as B
-import qualified Data.ByteString.Lazy.Char8 as L
-import qualified Data.HashMap.Strict as Map
+import           Data.ByteString.Char8                (ByteString)
+import qualified Data.ByteString.Char8                as B
+import qualified Data.ByteString.Lazy.Char8           as L
+import qualified Data.HashMap.Strict                  as Map
+import           Data.Map.Syntax
 import           Data.Maybe
 import           Data.Monoid
-import qualified Data.Text as T
-import qualified Data.Text.Encoding as T
-import           Data.Text (Text)
+import           Data.Text                            (Text)
+import qualified Data.Text                            as T
+import qualified Data.Text.Encoding                   as T
 import           System.IO.Unsafe
-import           Test.Framework (Test)
+import           Test.Framework                       (Test)
 import           Test.Framework.Providers.HUnit
 import           Test.Framework.Providers.QuickCheck2
-import qualified Test.HUnit as H
+import qualified Test.HUnit                           as H
 import           Test.QuickCheck
 import           Test.QuickCheck.Monadic
 
@@ -41,9 +42,9 @@ import           Heist.Splices.Ignore
 import           Heist.Splices.Json
 import           Heist.Splices.Markdown
 import           Heist.TestCommon
-import           Heist.Types
-import qualified Text.XmlHtml        as X
-import qualified Text.XmlHtml.Cursor as X
+import           Heist.Internal.Types
+import qualified Text.XmlHtml                         as X
+import qualified Text.XmlHtml.Cursor                  as X
 
 
 ------------------------------------------------------------------------------
@@ -117,7 +118,7 @@ addTest = do
 hasTemplateTest :: H.Assertion
 hasTemplateTest = do
     ets <- loadIO "templates" mempty mempty mempty mempty
-    let tm = either (error "Error loading templates") _templateMap ets
+    let tm = either (error . unlines) _templateMap ets
     hs <- loadEmpty mempty mempty mempty mempty
     let hs's = setTemplates tm hs
     H.assertBool "hasTemplate hs's" (hasTemplate "index" hs's)
@@ -138,7 +139,7 @@ loadTest = do
     ets <- loadIO "templates" mempty mempty mempty mempty
     either (error "Error loading templates")
            (\ts -> do let tm = _templateMap ts
-                      H.assertEqual "loadTest size" 37 $ Map.size tm
+                      H.assertEqual "loadTest size" 38 $ Map.size tm
            ) ets
 
 
