@@ -7,25 +7,27 @@ module Heist.Tests
 ------------------------------------------------------------------------------
 import           Blaze.ByteString.Builder
 import           Control.Monad.State
-import qualified Data.ByteString.Char8 as B
+import qualified Data.ByteString.Char8           as B
 import           Data.List
+import           Data.Map.Syntax
 import           Data.Maybe
 import           Data.Monoid
-import qualified Data.Text as T
-import           Test.Framework (Test)
+import qualified Data.Text                       as T
+import           Test.Framework                  (Test)
 import           Test.Framework.Providers.HUnit
-import qualified Test.HUnit as H
+import qualified Test.HUnit                      as H
 
 
 ------------------------------------------------------------------------------
 import           Heist
-import qualified Heist.Compiled as C
-import           Heist.Tutorial.AttributeSplices
-import           Heist.Tutorial.CompiledSplices
-import qualified Heist.Interpreted as I
+import qualified Heist.Compiled                  as C
+import           Heist.Internal.Types
+import qualified Heist.Interpreted               as I
 import           Heist.Splices.Cache
 import           Heist.Splices.Html
 import           Heist.TemplateDirectory
+import           Heist.Tutorial.AttributeSplices
+import           Heist.Tutorial.CompiledSplices
 
 import           Heist.TestCommon
 
@@ -34,8 +36,8 @@ tests = [ testCase     "loadErrors"            loadErrorsTest
         , testCase     "attrsplice/autocheck"  attrSpliceTest
         , testCase     "tdirCache"             tdirCacheTest
         , testCase     "headMerge"             headMergeTest
-        , testCase     "bindApplyInteraction"  bindApplyInteractionTest 
-        , testCase     "backslashHandling"     backslashHandlingTest 
+        , testCase     "bindApplyInteraction"  bindApplyInteractionTest
+        , testCase     "backslashHandling"     backslashHandlingTest
         ]
 
 
@@ -79,8 +81,8 @@ attrSpliceTest = do
   where
     expected1 = "<input type='checkbox' value='foo' checked />\n<input type='checkbox' value='bar' />\n"
     expected2 = "<input type='checkbox' value='foo' />\n<input type='checkbox' value='bar' checked />\n"
-    expected3 = "<input type=\"checkbox\" value=\"foo\" checked />&#10;<input type=\"checkbox\" value=\"bar\" />&#10;"
-    expected4 = "<input type=\"checkbox\" value=\"foo\" />&#10;<input type=\"checkbox\" value=\"bar\" checked />&#10;"
+    expected3 = mappend doctype "\n<input type=\"checkbox\" value=\"foo\" checked />&#10;<input type=\"checkbox\" value=\"bar\" />&#10;"
+    expected4 = mappend doctype "\n<input type=\"checkbox\" value=\"foo\" />&#10;<input type=\"checkbox\" value=\"bar\" checked />&#10;"
 
 fooSplice :: I.Splice (StateT Int IO)
 fooSplice = do
@@ -92,9 +94,10 @@ tdirCacheTest :: IO ()
 tdirCacheTest = do
     let rSplices = ("foosplice" ## fooSplice)
         dSplices = ("foosplice" ## stateSplice)
-        hc = HeistConfig rSplices mempty dSplices mempty mempty
+        sc = SpliceConfig rSplices mempty dSplices mempty mempty
+        hc = HeistConfig sc "" False
     td <- newTemplateDirectory' "templates" hc
-            
+
     [a,b,c,d] <- evalStateT (testInterpreted td) 5
     H.assertBool "interpreted doesn't cache" $ a == b
     H.assertBool "interpreted doesn't clear" $ b /= c
@@ -149,7 +152,8 @@ headMergeTest = do
       (toByteString mres)
   where
     expected = B.intercalate "\n"
-      ["<html><head>\n<link href='wrapper-link' />\n"
+      [doctype
+      ,"<html><head>\n<link href='wrapper-link' />\n"
       ,"<link href='nav-link' />\n\n<link href='index-link' />"
       ,"</head>\n\n<body>\n\n<div>nav bar</div>\n\n\n"
       ,"<div>index page</div>\n\n</body>\n</html>&#10;&#10;"
@@ -166,7 +170,8 @@ bindApplyInteractionTest = do
     H.assertEqual "interpreted failure" iExpected iOut
   where
     cExpected = B.intercalate "\n"
-      ["&#10;This is a test."
+      [doctype
+      ,"&#10;This is a test."
       ,"===bind content===&#10;Another test line."
       ,"apply content&#10;Last test line."
       ,"&#10;"
@@ -192,6 +197,6 @@ backslashHandlingTest = do
     iOut <- iRender hs "backslash"
     H.assertEqual "interpreted failure" iExpected iOut
   where
-    cExpected = "<foo regex='abc\\d+\\\\e'></foo>&#10;"
+    cExpected = mappend doctype "\n<foo regex='abc\\d+\\\\e'></foo>&#10;"
     iExpected = "<foo regex='abc\\d+\\\\e'></foo>\n"
 
